@@ -15,10 +15,10 @@
 
 
 import abc
-import json
 import tempfile
 
 from oslo_log import log
+from oslo_serialization import jsonutils as json
 import six
 
 from freezer.utils import utils
@@ -285,7 +285,6 @@ class Backup(object):
         with open(file.name) as f:
             content = f.readlines()
         LOG.info("Content download {0}".format(content))
-        file.close()
         return json.loads(content[0])
 
     def metadata(self):
