@@ -15,21 +15,24 @@
 
 import distutils.spawn
 import hashlib
-import json
 import itertools
 import os
+import random
 import shutil
-import six
 import subprocess
 import tempfile
 import unittest
+
+from oslo_serialization import jsonutils as json
+
 import paramiko
 
+from six.moves import range
+
 FREEZERC = distutils.spawn.find_executable('freezer-agent')
 
 
 class CommandFailed(Exception):
-
     def __init__(self, returncode, cmd, output, stderr):
         super(CommandFailed, self).__init__()
         self.returncode = returncode
@@ -45,13 +48,12 @@ class CommandFailed(Exception):
 
 
 def dict_to_args(d):
-    l = [['--' + k.replace('_', '-'), v] for k, v in six.iteritems(d)]
+    l = [['--' + k.replace('_', '-'), v] for k, v in d.items()]
     return list(itertools.chain.from_iterable(l))
 
 
 def execute_freezerc(dict, must_fail=False, merge_stderr=False):
     """
-
     :param dict:
     :type dict: dict[str, str]
     :param must_fail:
@@ -77,14 +79,15 @@ def execute(args, must_fail=False, merge_stderr=False):
     result, result_err = proc.communicate()
 
     if not must_fail and proc.returncode != 0:
-        raise CommandFailed(proc.returncode, ' '.join(args), result, result_err)
+        raise CommandFailed(proc.returncode, ' '.join(args), result,
+                            result_err)
     if must_fail and proc.returncode == 0:
-        raise CommandFailed(proc.returncode, ' '.join(args), result, result_err)
+        raise CommandFailed(proc.returncode, ' '.join(args), result,
+                            result_err)
     return result
 
 
 class Temp_Tree(object):
-
     def __init__(self, suffix='', dir=None, create=True):
         self.create = create
         if create:
@@ -106,20 +109,26 @@ class Temp_Tree(object):
 
     def add_random_data(self, ndir=5, nfile=5, size=1024):
         """
-        add some files containing randoma data
+        add some files containing random data
 
         :param ndir: number of dirs to create
         :param nfile: number of files to create in each dir
         :param size: size of files
         :return: None
         """
-        for x in range(ndir):
+        def create_file(path):
+            abs_pathname = self.create_file_with_random_data(
+                dir_path=path, size=size)
+            rel_path_name = abs_pathname[len(self.path) + 1:]
+            self.files.append(rel_path_name)
+
+        for _ in range(nfile):
+            create_file(self.path)
+
+        for _ in range(ndir):
             subdir_path = tempfile.mkdtemp(dir=self.path)
-            for y in range(nfile):
-                abs_pathname = self.create_file_with_random_data(
-                    dir_path=subdir_path, size=size)
-                rel_path_name = abs_pathname[len(self.path)+1:]
-                self.files.append(rel_path_name)
+            for _ in range(nfile):
+                create_file(subdir_path)
 
     def create_file_with_random_data(self, dir_path, size=1024):
         handle, abs_pathname = tempfile.mkstemp(dir=dir_path)
@@ -127,6 +136,24 @@ class Temp_Tree(object):
             fd.write(os.urandom(size))
         return abs_pathname
 
+    def modify_random_files(self, count=1):
+        indexes = []
+        for _ in range(count):
+            indexes.append(random.randint(0, len(self.files) - 1))
+        for file_index in indexes:
+            file_name = self.files[file_index]
+            with open(os.path.join(self.path, file_name), 'ab') as fd:
+                size_to_add = int(fd.tell() * 0.5)
+                fd.write(os.urandom(size_to_add))
+
+    def delete_random_files(self, count=1):
+        indexes = []
+        for _ in range(count):
+            indexes.append(random.randint(0, len(self.files) - 1))
+        for file_index in indexes:
+            file_name = self.files[file_index]
+            os.unlink(os.path.join(self.path, file_name))
+
     def get_file_hash(self, rel_filepath):
         filepath = os.path.join(self.path, rel_filepath)
         if os.path.isfile(filepath):
@@ -155,7 +182,7 @@ class Temp_Tree(object):
         """
         self.files = []
         for root, dirs, files in os.walk(self.path):
-            rel_base = root[len(self.path)+1:]
+            rel_base = root[len(self.path) + 1:]
             self.files.extend([os.path.join(rel_base, x) for x in files])
         return self.files
 
@@ -191,22 +218,22 @@ class TestFS(unittest.TestCase):
 
     To enable the ssh storage testing, the following environment
     variables need to be defined:
-     - FREEZER_TEST_SSH_KEY
-     - FREEZER_TEST_SSH_USERNAME
-     - FREEZER_TEST_SSH_HOST
-     - FREEZER_TEST_CONTAINER
+    - FREEZER_TEST_SSH_KEY
+    - FREEZER_TEST_SSH_USERNAME
+    - FREEZER_TEST_SSH_HOST
+    - FREEZER_TEST_CONTAINER
 
     To enable the swift storage testing, the following environment
     variables need to be defined:
-     - FREEZER_TEST_OS_TENANT_NAME
-     - FREEZER_TEST_OS_USERNAME
-     - FREEZER_TEST_OS_REGION_NAME
-     - FREEZER_TEST_OS_PASSWORD
-     - FREEZER_TEST_OS_AUTH_URL
+    - FREEZER_TEST_OS_TENANT_NAME
+    - FREEZER_TEST_OS_USERNAME
+    - FREEZER_TEST_OS_REGION_NAME
+    - FREEZER_TEST_OS_PASSWORD
+    - FREEZER_TEST_OS_AUTH_URL
 
     Tests involving LVM snapshots are evoided if:
-     - user is not root
-     - FREEZER_TEST_NO_LVM is set
+    - user is not root
+    - FREEZER_TEST_NO_LVM is set
     """
 
     ssh_key = os.environ.get('FREEZER_TEST_SSH_KEY')
@@ -220,8 +247,8 @@ class TestFS(unittest.TestCase):
     os_region = os.environ.get('FREEZER_TEST_OS_REGION_NAME')
     os_password = os.environ.get('FREEZER_TEST_OS_PASSWORD')
     os_auth_url = os.environ.get('FREEZER_TEST_OS_AUTH_URL')
-    use_os = (os_tenant_name and os_user_name and os_region
-              and os_password and os_auth_url)
+    use_os = (os_tenant_name and os_user_name and os_region and
+              os_password and os_auth_url)
     if use_os:
         os.environ['OS_USERNAME'] = os_user_name
         os.environ['OS_TENANT_NAME'] = os_tenant_name
@@ -269,7 +296,7 @@ class TestFS(unittest.TestCase):
     def get_file_list_openstack(self, container):
         if self.openstack_executable:
             json_result = execute([self.openstack_executable, 'object', 'list',
-                                   container, '-f', json])
+                                   container, '-f', 'json'])
             result = json.loads(json_result)
             return [x['Name'] for x in result]
         if self.swift_executable:
