@@ -1,21 +1,23 @@
+# Copyright 2015 Hewlett-Packard
+# (c) Copyright 2016 Hewlett Packard Enterprise Development Company LP
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 """
-Copyright 2015 Hewlett-Packard
-(c) Copyright 2016 Hewlett Packard Enterprise Development Company LP
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-
 Freezer general utils functions
 """
+
 import datetime
 import errno
 import fnmatch as fn
@@ -262,8 +264,8 @@ class ReSizeStream(object):
         return self
 
     def next(self):
-        LOG.info("Transmitted {0} of {1}".format(self.transmitted,
-                                                 self.length))
+        LOG.debug("Transmitted {0} of {1}".format(self.transmitted,
+                                                  self.length))
         chunk_size = self.chunk_size
         if len(self.reminder) > chunk_size:
             result = self.reminder[:chunk_size]
